"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PlayerVoteArea = void 0;
const PlayerVoteState_1 = require("./PlayerVoteState");
class PlayerVoteArea {
    constructor(room, playerId, votedForId, didReport) {
        this.room = room;
        this.playerId = playerId;
        this.votedForId = votedForId;
        this.didReport = didReport;
        this.dirty = false;
    }
    /**
     * The player that this vote state is for.
     */
    get player() {
        return this.room.getPlayerByPlayerId(this.playerId);
    }
    /**
     * Whether the player that this state represents is dead.
     */
    get isDead() {
        return this.votedForId === PlayerVoteState_1.VoteStateSpecialId.IsDead;
    }
    /**
     * Whether this player didn't vote by the end of the meeting.
     */
    get didMissVote() {
        return this.votedForId === PlayerVoteState_1.VoteStateSpecialId.MissedVote;
    }
    /**
     * Whether this player skipped voting.
     */
    get didSkip() {
        return this.votedForId === PlayerVoteState_1.VoteStateSpecialId.SkippedVote;
    }
    /**
     * Whether this player has either voted for a player or voted to skip.
     */
    get hasVoted() {
        return this.votedForId < PlayerVoteState_1.VoteStateSpecialId.IsDead ||
            this.votedForId === PlayerVoteState_1.VoteStateSpecialId.SkippedVote;
    }
    /**
     * The player that this player voted for, if any.
     */
    get votedFor() {
        if (this.votedForId >= PlayerVoteState_1.VoteStateSpecialId.IsDead)
            return undefined;
        return this.room.getPlayerByPlayerId(this.votedForId);
    }
    static Deserialize(reader, room, playerId) {
        const votedForId = reader.uint8();
        const didReport = reader.bool();
        return new PlayerVoteArea(room, playerId, votedForId, didReport);
    }
    Serialize(writer) {
        writer.uint8(this.votedForId);
        writer.bool(this.didReport);
    }
    clearVote() {
        this.votedForId = PlayerVoteState_1.VoteStateSpecialId.NotVoted;
    }
    setSkipped() {
        this.votedForId = PlayerVoteState_1.VoteStateSpecialId.SkippedVote;
    }
    setDead() {
        return this.votedForId = PlayerVoteState_1.VoteStateSpecialId.IsDead;
    }
    setSuspect(playerId) {
        if (playerId >= 252) {
            throw new RangeError("Suspect player ID cannot be greater than 252.");
        }
        this.votedForId = playerId;
    }
}
exports.PlayerVoteArea = PlayerVoteArea;
//# sourceMappingURL=PlayerVoteArea.js.map