import { HazelReader } from "@skeldjs/util";
import { SpawnType, SystemType } from "@skeldjs/constant";
import { ShipStatusData, InnerShipStatus } from "./InnerShipStatus";
import { Hostable } from "../Hostable";
import { AutoDoorsSystem, HudOverrideSystem, SabotageSystem, SecurityCameraSystem, SwitchSystem, ElectricalDoorsSystem, MovingPlatformSystem } from "../systems";
import { Networkable, NetworkableConstructor } from "../Networkable";
/**
 * Represents a room object for the Airship map.
 *
 * See {@link ShipStatusEvents} for events to listen to.
 */
export declare class AirshipStatus<RoomType extends Hostable = Hostable> extends InnerShipStatus<RoomType> {
    static roomDoors: {
        14: number[];
        40: number[];
        33: number[];
        45: number[];
        42: number[];
        43: number[];
        46: number[];
    };
    systems: {
        [SystemType.Electrical]: SwitchSystem<RoomType>;
        [SystemType.Security]: SecurityCameraSystem<RoomType>;
        [SystemType.Communications]: HudOverrideSystem<RoomType>;
        [SystemType.Sabotage]: SabotageSystem<RoomType>;
        [SystemType.GapRoom]: MovingPlatformSystem<RoomType>;
        [SystemType.Decontamination]: ElectricalDoorsSystem<RoomType>;
        [SystemType.Decontamination2]: AutoDoorsSystem<RoomType>;
    };
    constructor(room: RoomType, spawnType: SpawnType, netid: number, ownerid: number, flags: number, data?: HazelReader | ShipStatusData);
    getComponent<T extends Networkable>(component: NetworkableConstructor<T>): T | undefined;
    Setup(): void;
}
