import { HazelReader, HazelWriter } from "@skeldjs/util";
import { SpawnType, SystemType } from "@skeldjs/constant";
import { ExtractEventTypes } from "@skeldjs/events";
import { BaseRpcMessage } from "@skeldjs/protocol";
import { AutoDoorsSystemEvents, DeconSystemEvents, DoorsSystemEvents, ElectricalDoorsSystemEvents, HqHudSystemEvents, HudOverrideSystemEvents, LifeSuppSystemEvents, MedScanSystemEvents, MovingPlatformSystemEvents, ReactorSystemEvents, SabotageSystemEvents, SecurityCameraSystemEvents, SwitchSystemEvents, SystemStatus } from "../systems";
import { Networkable, NetworkableEvents } from "../Networkable";
import { Hostable } from "../Hostable";
import { SystemStatusEvents } from "../systems/events";
import { RoomSelectImpostorsEvent } from "../events";
declare type AllSystems = Partial<Record<SystemType, SystemStatus<any, any>>>;
export interface ShipStatusData {
    systems: AllSystems;
}
export declare type ShipStatusEvents<RoomType extends Hostable = Hostable> = NetworkableEvents<RoomType> & DoorsSystemEvents<RoomType> & SystemStatusEvents<RoomType> & AutoDoorsSystemEvents<RoomType> & DeconSystemEvents<RoomType> & ElectricalDoorsSystemEvents<RoomType> & HqHudSystemEvents<RoomType> & HudOverrideSystemEvents<RoomType> & LifeSuppSystemEvents<RoomType> & MedScanSystemEvents<RoomType> & MovingPlatformSystemEvents<RoomType> & ReactorSystemEvents<RoomType> & SabotageSystemEvents<RoomType> & SecurityCameraSystemEvents<RoomType> & SwitchSystemEvents<RoomType> & ExtractEventTypes<[RoomSelectImpostorsEvent<RoomType>]>;
export declare type ShipStatusType = SpawnType.ShipStatus | SpawnType.Headquarters | SpawnType.PlanetMap | SpawnType.AprilShipStatus | SpawnType.Airship;
export declare type ShipStatusClassname = "ShipStatus" | "Headquarters" | "PlanetMap" | "AprilShipStatus" | "Airship";
export declare class InnerShipStatus<RoomType extends Hostable = Hostable> extends Networkable<ShipStatusData, ShipStatusEvents<RoomType>, RoomType> {
    static roomDoors: Partial<Record<SystemType, number[]>>;
    systems: AllSystems;
    constructor(room: RoomType, spawnType: SpawnType, netid: number, ownerid: number, flags: number, data?: HazelReader | ShipStatusData);
    get owner(): RoomType;
    Setup(): void;
    Deserialize(reader: HazelReader, spawn?: boolean): void;
    Serialize(writer: HazelWriter, spawn?: boolean): boolean;
    HandleRpc(rpc: BaseRpcMessage): Promise<void>;
    FixedUpdate(delta: number): void;
    private _handleRepairSystem;
    /**
     * Randomly select players to be the Impostor. Called after a game is started
     * and emits a {@link RoomSelectImpostorsEvent} which can be used to alter the
     * results of this function.
     */
    selectImpostors(): Promise<void>;
    private getTasksForMap;
    private addTasksFromList;
    assignTasks(): Promise<void>;
}
export {};
