import { HazelReader } from "@skeldjs/util";
import { SpawnType, SystemType } from "@skeldjs/constant";
import { DeconSystem, HqHudSystem, LifeSuppSystem, MedScanSystem, ReactorSystem, SabotageSystem, SwitchSystem } from "../systems";
import { Networkable, NetworkableConstructor } from "../Networkable";
import { InnerShipStatus, ShipStatusData } from "./InnerShipStatus";
import { Hostable } from "../Hostable";
/**
 * Represents a room object for the Mira HQ map.
 *
 * See {@link ShipStatusEvents} for events to listen to.
 */
export declare class MiraShipStatus<RoomType extends Hostable = Hostable> extends InnerShipStatus<RoomType> {
    systems: {
        [SystemType.Reactor]: ReactorSystem<RoomType>;
        [SystemType.Electrical]: SwitchSystem<RoomType>;
        [SystemType.O2]: LifeSuppSystem<RoomType>;
        [SystemType.MedBay]: MedScanSystem<RoomType>;
        [SystemType.Communications]: HqHudSystem<RoomType>;
        [SystemType.Sabotage]: SabotageSystem<RoomType>;
        [SystemType.Decontamination]: DeconSystem<RoomType>;
    };
    constructor(room: RoomType, spawnType: SpawnType, netid: number, ownerid: number, flags: number, data?: HazelReader | ShipStatusData);
    getComponent<T extends Networkable>(component: NetworkableConstructor<T>): T | undefined;
    get owner(): RoomType;
    Setup(): void;
}
