import { SpawnType, SystemType } from "@skeldjs/constant";
import { BaseRpcMessage } from "@skeldjs/protocol";
import { HazelReader } from "@skeldjs/util";
import { DeconSystem, HudOverrideSystem, MedScanSystem, ReactorSystem, SabotageSystem, SwitchSystem, DoorsSystem, SecurityCameraSystem } from "../systems";
import { ShipStatusData, InnerShipStatus } from "./InnerShipStatus";
import { Hostable } from "../Hostable";
import { Networkable, NetworkableConstructor } from "../Networkable";
/**
 * Represents a room object for the Polus map.
 *
 * See {@link ShipStatusEvents} for events to listen to.
 */
export declare class PolusShipStatus<RoomType extends Hostable = Hostable> extends InnerShipStatus<RoomType> {
    static roomDoors: {
        7: number[];
        8: number[];
        12: number[];
        14: number[];
        23: number[];
        21: number[];
        1: number[];
        18: number[];
    };
    systems: {
        [SystemType.Electrical]: SwitchSystem<RoomType>;
        [SystemType.MedBay]: MedScanSystem<RoomType>;
        [SystemType.Security]: SecurityCameraSystem<RoomType>;
        [SystemType.Communications]: HudOverrideSystem<RoomType>;
        [SystemType.Doors]: DoorsSystem<RoomType>;
        [SystemType.Sabotage]: SabotageSystem<RoomType>;
        [SystemType.Decontamination]: DeconSystem<RoomType>;
        [SystemType.Decontamination2]: DeconSystem<RoomType>;
        [SystemType.Laboratory]: ReactorSystem<RoomType>;
    };
    constructor(room: RoomType, spawnType: SpawnType, netid: number, ownerid: number, flags: number, data?: HazelReader | ShipStatusData);
    getComponent<T extends Networkable>(component: NetworkableConstructor<T>): T | undefined;
    HandleRpc(rpc: BaseRpcMessage): Promise<void>;
    private _handleCloseDoorsOfType;
    Setup(): void;
}
