"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PolusShipStatus = void 0;
const constant_1 = require("@skeldjs/constant");
const systems_1 = require("../systems");
const Door_1 = require("../misc/Door");
const InnerShipStatus_1 = require("./InnerShipStatus");
/**
 * Represents a room object for the Polus map.
 *
 * See {@link ShipStatusEvents} for events to listen to.
 */
class PolusShipStatus extends InnerShipStatus_1.InnerShipStatus {
    constructor(room, spawnType, netid, ownerid, flags, data) {
        super(room, spawnType, netid, ownerid, flags, data);
    }
    getComponent(component) {
        if (component === PolusShipStatus) {
            return this.components[0];
        }
        return undefined;
    }
    async HandleRpc(rpc) {
        switch (rpc.messageTag) {
            case constant_1.RpcMessageTag.CloseDoorsOfType:
                await this._handleCloseDoorsOfType(rpc);
                break;
            default:
                await super.HandleRpc(rpc);
                break;
        }
    }
    async _handleCloseDoorsOfType(rpc) {
        const doorsinRoom = PolusShipStatus.roomDoors[rpc.systemid];
        for (const doorId of doorsinRoom) {
            this.systems[constant_1.SystemType.Doors].closeDoor(doorId);
        }
    }
    Setup() {
        this.systems = {
            [constant_1.SystemType.Electrical]: new systems_1.SwitchSystem(this, {
                expected: [false, false, false, false, false],
                actual: [false, false, false, false, false],
                brightness: 100,
            }),
            [constant_1.SystemType.MedBay]: new systems_1.MedScanSystem(this, {
                queue: [],
            }),
            [constant_1.SystemType.Security]: new systems_1.SecurityCameraSystem(this, {
                players: new Set,
            }),
            [constant_1.SystemType.Communications]: new systems_1.HudOverrideSystem(this, {
                sabotaged: false,
            }),
            [constant_1.SystemType.Doors]: new systems_1.DoorsSystem(this, {
                doors: [],
                cooldowns: new Map,
            }),
            [constant_1.SystemType.Sabotage]: new systems_1.SabotageSystem(this, {
                cooldown: 0,
            }),
            [constant_1.SystemType.Decontamination]: new systems_1.DeconSystem(this, {
                timer: 10000,
                state: 0,
            }),
            [constant_1.SystemType.Decontamination2]: new systems_1.DeconSystem(this, {
                timer: 10000,
                state: 0,
            }),
            [constant_1.SystemType.Laboratory]: new systems_1.ReactorSystem(this, {
                timer: 10000,
                completed: new Set,
            }),
        };
        const doorsystem = this.systems[constant_1.SystemType.Doors];
        doorsystem.doors = [
            new Door_1.Door(doorsystem, 0, true),
            new Door_1.Door(doorsystem, 1, true),
            new Door_1.Door(doorsystem, 2, true),
            new Door_1.Door(doorsystem, 3, true),
            new Door_1.Door(doorsystem, 4, true),
            new Door_1.Door(doorsystem, 5, true),
            new Door_1.Door(doorsystem, 6, true),
            new Door_1.Door(doorsystem, 7, true),
            new Door_1.Door(doorsystem, 8, true),
            new Door_1.Door(doorsystem, 9, true),
            new Door_1.Door(doorsystem, 10, true),
            new Door_1.Door(doorsystem, 11, true),
        ];
    }
}
exports.PolusShipStatus = PolusShipStatus;
PolusShipStatus.roomDoors = {
    [constant_1.SystemType.Electrical]: [0, 1, 2],
    [constant_1.SystemType.O2]: [3, 4],
    [constant_1.SystemType.Weapons]: [5],
    [constant_1.SystemType.Communications]: [7],
    [constant_1.SystemType.Office]: [7, 8],
    [constant_1.SystemType.Laboratory]: [9, 10],
    [constant_1.SystemType.Storage]: [11],
    [constant_1.SystemType.Decontamination]: [12, 13, 14, 15]
};
//# sourceMappingURL=PolusShipStatus.js.map